@@ -22,11 +22,14 @@ from _libsemigroups_pybind11 import (
     add_identity_rules,
     add_inverse_rules,
     remove_duplicate_rules,
+    remove_trivial_rules,
+    remove_redundant_generators,
     reduce_complements,
     sort_each_rule,
     sort_rules,
     longest_common_subword,
     replace_subword,
+    replace_word,
     length,
     reverse,
     normalize_alphabet,
