@@ -62,7 +62,7 @@ namespace libsemigroups {
       return result;
     }
   }  // namespace libsemigroups_pybind11
-     //
+
   using node_type = ActionDigraph<size_t>::node_type;
   using algorithm = ActionDigraph<size_t>::algorithm;
   void init_action_digraph(py::module& m) {
@@ -121,6 +121,7 @@ namespace libsemigroups {
                result += " out-degree>";
                return result;
              })
+        .def("__str__", &detail::to_string<ActionDigraph<size_t>>)
         .def(pybind11::self == pybind11::self)
         .def("number_of_nodes",
              &ActionDigraph<size_t>::number_of_nodes,
@@ -817,8 +818,9 @@ namespace libsemigroups {
     ////////////////////////////////////////////////////////////////////////
     // action_digraph_helper
     ////////////////////////////////////////////////////////////////////////
-    // TODO(later) there are several functions in action_digraph_helper that
-    // can be included here!
+
+    // TODO(later) there are several more functions in action_digraph_helper
+    // that can be included here!
 
     m.def("add_cycle",
           py::overload_cast<ActionDigraph<size_t>&, size_t>(
@@ -904,8 +906,12 @@ namespace libsemigroups {
               if ``source`` is not a node in the digraph or ``path`` contains a
               value that is not an edge-label.
           )pbdoc");
-    m.def("action_digraph_helper_make",
+    m.def("make",
+          // see docs/source/api/digraph-helper.rst for the doc, it's there
+          // because otherwise we are documenting the overloaded function
+          // `make`, and the doc here is not picked up.
           &libsemigroups_pybind11::make,
-          R"pbdoc( TODO )pbdoc");
+          py::arg("num_nodes"),
+          py::arg("l"));
   }
 }  // namespace libsemigroups
