@@ -46,9 +46,7 @@ namespace libsemigroups {
   namespace {
 
     template <typename T>
-    std::string presentation_repr(Presentation<T>& p) {
-      // FIXME presentation::length does not take const refs but refs and so we
-      // must do the same.
+    std::string presentation_repr(Presentation<T> const& p) {
       std::ostringstream out;
 
       out << "<" << (p.contains_empty_word() ? "monoid" : "semigroup")
@@ -98,6 +96,7 @@ namespace libsemigroups {
       m.def("add_identity_rules", &presentation::add_identity_rules<T>);
       m.def("add_inverse_rules", &presentation::add_inverse_rules<T>);
       m.def("remove_duplicate_rules", &presentation::remove_duplicate_rules<T>);
+      m.def("remove_trivial_rules", &presentation::remove_trivial_rules<T>);
       m.def("reduce_complements", &presentation::reduce_complements<T>);
       m.def("sort_each_rule", &presentation::sort_each_rule<T>);
       m.def("sort_rules", &presentation::sort_rules<T>);
@@ -105,9 +104,17 @@ namespace libsemigroups {
       m.def("replace_subword",
             py::overload_cast<Presentation<T>&, T const&>(
                 &presentation::replace_subword<T>));
+      m.def(
+          "replace_subword",
+          [](Presentation<T>& p, T const& existing, T const& replace) -> void {
+            presentation::replace_subword(p, existing, replace);
+          });
+      m.def("replace_word", &presentation::replace_word<T>);
       m.def("length", &presentation::length<T>);
       m.def("reverse", &presentation::reverse<T>);
       m.def("normalize_alphabet", &presentation::normalize_alphabet<T>);
+      m.def("remove_redundant_generators",
+            &presentation::remove_redundant_generators<T>);
 
       m.def(
           "make",
